# 2.6 Pin 模块API手册

![cover](../images/canaan-cover.png)

版权所有©2023北京嘉楠捷思信息技术有限公司

<div style="page-break-after:always"></div>

## 免责声明

您购买的产品、服务或特性等应受北京嘉楠捷思信息技术有限公司（“本公司”，下同）及其关联公司的商业合同和条款的约束，本文档中描述的全部或部分产品、服务或特性可能不在您的购买或使用范围之内。除非合同另有约定，本公司不对本文档的任何陈述、信息、内容的正确性、可靠性、完整性、适销性、符合特定目的和不侵权提供任何明示或默示的声明或保证。除非另有约定，本文档仅作为使用指导参考。

由于产品版本升级或其他原因，本文档内容将可能在未经任何通知的情况下，不定期进行更新或修改。

## 商标声明

![logo](../images/logo.png)、“嘉楠”和其他嘉楠商标均为北京嘉楠捷思信息技术有限公司及其关联公司的商标。本文档可能提及的其他所有商标或注册商标，由各自的所有人拥有。

**版权所有 © 2023北京嘉楠捷思信息技术有限公司。保留一切权利。**
非经本公司书面许可，任何单位和个人不得擅自摘抄、复制本文档内容的部分或全部，并不得以任何形式传播。

<div style="page-break-after:always"></div>

## 目录

[TOC]

## 前言

### 概述

本文档主要介绍machine模块下的Pin类API。

### 读者对象

本文档（本指南）主要适用于以下人员：

- 技术支持工程师
- 软件开发工程师

### 缩略词定义

| 简称 | 说明 |
| ---- | ---- |
| GPIO  |  General Purpose Input Output （通用输入/输出）  |

### 修订记录

| 文档版本号 | 修改说明 | 修改者     | 日期       |
| ---------- | -------- | ---------- | ---------- |
| V1.0       | 初版     | 软件部      | 2023-09-20 |

## 1. 概述

K230内部包含64个GPIO Pin，每个Pin可配置为输入或输出，可配置上下拉，可配置驱动能力。

## 2. API描述

Pin类位于machine模块下

### 示例

```python
from machine import Pin
# 实例化Pin2为输出
pin = Pin(2, Pin.OUT, pull=Pin.PULL_NONE, drive=7)
# 设置输出为高
pin.value(1)
# 设置输出为低
pin.value(0)
```

### 构造函数

```python
pin = Pin(index, mode, pull=Pin.PULL_NONE, drive=7)
```

【参数】

- index: 引脚号，取值:[0,63]
- mode: 输入或输出模式
- pull: 上下拉配置，可选参数，默认PULL_NONE
- drive: 驱动能力配置，可选参数，默认7

### init

```python
Pin.init(mode, pull=Pin.PULL_NONE, drive=7)
```

配置引脚模式，上下拉，驱动能力

【参数】

- mode: 输入或输出模式
- pull: 上下拉配置，可选参数，默认PULL_NONE
- drive: 驱动能力配置，可选参数，默认7

【返回值】

无

### value

```python
Pin.value([value])
```

获取引脚输入或设置引脚输出

【参数】

- value: 输出值，可选参数，如果不传参数则返回输入值

【返回值】

返回空或当前引脚输入值

### mode

```python
Pin.mode([mode])
```

获取或设置引脚输入输出模式

【参数】

- mode: 输入输出模式，可选参数，如果不传参数则返回当前输入输出模式

【返回值】

返回空或当前引脚输入输出模式

### pull

```python
Pin.pull([pull])
```

获取或设置引脚上下拉配置

【参数】

- pull: 上下拉配置，可选参数，如果不传参数则返回当前上下拉配置

【返回值】

返回空或当前引脚上下拉配置

### drive

```python
Pin.drive([drive])
```

获取或设置引脚驱动能力

【参数】

- drive: 驱动能力，可选参数，如果不传参数则返回当前驱动能力

【返回值】

返回空或当前引脚驱动能力

### on

```python
Pin.on()
```

设置输出高

【参数】

无

【返回值】

无

### off

```python
Pin.off()
```

设置输出低

【参数】

无

【返回值】

无

### high

```python
Pin.high()
```

设置输出高

【参数】

无

【返回值】

无

### low

```python
Pin.low()
```

设置输出低

【参数】

无

【返回值】

无
